@@ -31,15 +31,15 @@
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <KProtocolInfo>
+#include <kio_version.h>
+#include <KIO/StatJob>
+#include <KJobWidgets>
+
 #include <QMimeDatabase>
 #include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QWindow>
-
-#include <KIO/StatJob>
-#include <KJobWidgets>
-
 #include <QTextStream>
 
 namespace
@@ -106,11 +106,14 @@ KDEPlatformFileDialog::KDEPlatformFileDialog()
     m_buttons->addButton(m_fileWidget->okButton(), QDialogButtonBox::AcceptRole);
     m_buttons->addButton(m_fileWidget->cancelButton(), QDialogButtonBox::RejectRole);
     connect(m_buttons, SIGNAL(rejected()), m_fileWidget, SLOT(slotCancel()));
+    // Also call the cancel function when the dialog is closed via the escape key
+    // or titlebar close button to make sure we always save the view config
+    connect(this, &KDEPlatformFileDialog::rejected,
+            m_fileWidget, &KFileWidget::slotCancel);
     connect(m_fileWidget->okButton(), SIGNAL(clicked(bool)), m_fileWidget, SLOT(slotOk()));
     connect(m_fileWidget, SIGNAL(accepted()), m_fileWidget, SLOT(accept()));
     connect(m_fileWidget, SIGNAL(accepted()), SLOT(accept()));
     connect(m_fileWidget->cancelButton(), SIGNAL(clicked(bool)), SLOT(reject()));
-    connect(m_fileWidget->dirOperator(), &KDirOperator::urlEntered, this, &KDEPlatformFileDialogBase::directoryEntered);
     layout()->addWidget(m_buttons);
 }
 
@@ -326,6 +329,10 @@ void KDEPlatformFileDialogHelper::initializeDialog()
          } else if (options()->acceptMode() == QFileDialogOptions::AcceptSave) {
              dialog->m_fileWidget->setConfirmOverwrite(true);
         }
+
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 43, 0)
+        dialog->m_fileWidget->setSupportedSchemes(options()->supportedSchemes());
+#endif
     }
 }
 
