@@ -122,20 +122,15 @@ void QDBusMenuBar::syncMenu(QPlatformMenu *menu)
 
 void QDBusMenuBar::handleReparent(QWindow *newParentWindow)
 {
-    if (newParentWindow == m_window) {
-        return;
-    }
+    if (newParentWindow && newParentWindow != m_window) {
+        QWindow *oldWindow = m_window;
 
-    QWindow *oldWindow = m_window;
-
-    unregisterMenuBar();
-    m_window = newParentWindow;
-
-    if (newParentWindow) {
+        unregisterMenuBar();
+        m_window = newParentWindow;
         registerMenuBar();
-    }
 
-    emit windowChanged(newParentWindow, oldWindow);
+        emit windowChanged(newParentWindow, oldWindow);
+    }
 }
 
 QPlatformMenu *QDBusMenuBar::menuForTag(quintptr tag) const
@@ -192,6 +187,4 @@ void QDBusMenuBar::unregisterMenuBar()
         connection.unregisterObject(m_objectPath);
 }
 
-#include "qdbusmenubar.moc"
-
 QT_END_NAMESPACE
